@@ -67,7 +67,7 @@ notes_start_file (annocheck_data * data)
 }
 
 static bool
-notes_interesting_sec (annocheck_data *     data,
+notes_interesting_sec (annocheck_data *     data ATTRIBUTE_UNUSED,
 		       annocheck_section *  sec)
 {
   if (disabled)
@@ -118,7 +118,7 @@ notes_walk (annocheck_data *     data,
 	    GElf_Nhdr *          note,
 	    size_t               name_offset,
 	    size_t               data_offset,
-	    void *               ptr)
+	    void *               ptr ATTRIBUTE_UNUSED)
 {
   if (note->n_type != NT_GNU_BUILD_ATTRIBUTE_OPEN
       && note->n_type != NT_GNU_BUILD_ATTRIBUTE_FUNC)
@@ -269,7 +269,7 @@ display_GOW_values (unsigned long value, const char * ptr ATTRIBUTE_UNUSED)
 {
   einfo (PARTIAL, "GOW data: ");
 
-  if (value == -1)
+  if (value == (unsigned long) -1)
     {
       einfo (PARTIAL, "*unknown (-1)*\n");
       return false;
@@ -706,7 +706,7 @@ check_annobin_string_section (annocheck_data *    data,
 		/* For certain strings, if a name follows the note, it is
 		   the filename (and optionally the function name) of
 		   the non-conforming file.  */
-		char * space = strchr (ptr, ' ');
+		const char * space = strchr (ptr, ' ');
 
 		if (space != NULL)
 		  {
@@ -808,7 +808,7 @@ display_elf_notes (annocheck_data * data)
       switch (note->data[0])
 	{
 	case GNU_BUILD_ATTRIBUTE_VERSION:
-	  if (value == -1)
+	  if (value == (uint) -1)
 	    {
 	      einfo (PARTIAL, "Version: %s", note->data + 1);
 
@@ -834,7 +834,7 @@ display_elf_notes (annocheck_data * data)
 	  break;
 
 	case GNU_BUILD_ATTRIBUTE_TOOL:
-	  if (value == -1)
+	  if (value == (uint) -1)
 	    einfo (PARTIAL, "Tool: %s\n", note->data + 1);
 	  else
 	    einfo (PARTIAL, "Tool: %x (?)\n", value);
@@ -845,7 +845,7 @@ display_elf_notes (annocheck_data * data)
 	  break;
 
 	case GNU_BUILD_ATTRIBUTE_ABI:
-	  if (value == -1)
+	  if (value == (uint) -1)
 	    einfo (PARTIAL, "ABI: %s\n", note->data + 1);
 	  else
 	    einfo (PARTIAL, "ABI: %x\n", value);
@@ -1037,7 +1037,7 @@ notes_end_file (annocheck_data * data)
 }
 
 static bool
-notes_process_arg (const char * arg, const char ** argv, const uint argc, uint * next)
+notes_process_arg (const char * arg, const char ** argv ATTRIBUTE_UNUSED, const uint argc ATTRIBUTE_UNUSED, uint * next ATTRIBUTE_UNUSED)
 {
   if (arg[0] == '-')
     ++ arg;
